==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1條新消息</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>正在連接%1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1已斷開</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>未能加入%1，請檢查路由器或網線。</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>未能加入%1，請嘗試靠近無線路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>連接失敗，未能加入%1，密碼不正確</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>連接%1需要密碼</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN網絡無法找到</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>有線連接</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>熱點</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>協議</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全類型</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>接口</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網掩碼</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>主要 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>首碼</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>設備已禁用</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網絡但無法訪問互聯網</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認證中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>獲取IP位址</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已切斷連接</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>獲取地址中</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網絡 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網絡%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>設備已禁用</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網絡但無法訪問互聯網</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網絡</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網絡</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網絡</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用無線網絡</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>關閉網絡</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網絡</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網絡設置</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1條新消息</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>正在連接%1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1已斷開</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>未能加入%1，請檢查路由器或網線。</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>未能加入%1，請嘗試靠近無線路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>連接失敗，未能加入%1，密碼不正確</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>連接%1需要密碼</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN網絡無法找到</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>連接到隱藏網絡</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>連 接</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>請輸入網絡名稱（SSID）</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>熱點</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>協議</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全類型</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>接口</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網掩碼</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>主要 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>首碼</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>設備已禁用</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網絡但無法訪問互聯網</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認證中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>獲取IP位址</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已切斷連接</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>獲取地址中</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網絡 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網絡%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>設備已禁用</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網絡但無法訪問互聯網</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網絡</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網絡</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網絡</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用無線網絡</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>關閉網絡</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網絡</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網絡設置</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>有線連接</translation>
    </message>
</context>
</TS>
